@@ -434,3 +434,72 @@ def test_tokenization(lexer):
     ]
     actual = lexer.parse()
     assert actual == expected
+
+
+def test_multi_heterogeneous_list(lexer):
+    lexer.text = (
+        "languages:\n\tpython:\n\t\tformatter:\n\t\t\targs:\n\t\t\t\t- @str format"
+        '\n\t\t\t\t- @str "-q"\n\t\t\t\t- @str "-q"\n'
+    )
+    expected = [
+        Token(type=TokenType.KEY, value="languages", line=1, indent=0),
+        Token(type=TokenType.TYPE, value="unknown", line=1, indent=0),
+        Token(type=TokenType.NEWLINE, value="\n", line=1, indent=0),
+        Token(type=TokenType.KEY, value="python", line=2, indent=1),
+        Token(type=TokenType.TYPE, value="unknown", line=2, indent=1),
+        Token(type=TokenType.NEWLINE, value="\n", line=2, indent=1),
+        Token(type=TokenType.KEY, value="formatter", line=3, indent=2),
+        Token(type=TokenType.TYPE, value="unknown", line=3, indent=2),
+        Token(type=TokenType.NEWLINE, value="\n", line=3, indent=2),
+        Token(type=TokenType.KEY, value="args", line=4, indent=3),
+        Token(type=TokenType.TYPE, value="unknown", line=4, indent=3),
+        Token(type=TokenType.NEWLINE, value="\n", line=4, indent=3),
+        Token(type=TokenType.OPERATOR, value="-", line=5, indent=4),
+        Token(type=TokenType.TYPE, value="str", line=5, indent=4),
+        Token(type=TokenType.VALUE, value="format", line=5, indent=4),
+        Token(type=TokenType.NEWLINE, value="\n", line=5, indent=4),
+        Token(type=TokenType.OPERATOR, value="-", line=6, indent=4),
+        Token(type=TokenType.TYPE, value="str", line=6, indent=4),
+        Token(type=TokenType.VALUE, value="-q", line=6, indent=4),
+        Token(type=TokenType.NEWLINE, value="\n", line=6, indent=4),
+        Token(type=TokenType.OPERATOR, value="-", line=7, indent=4),
+        Token(type=TokenType.TYPE, value="str", line=7, indent=4),
+        Token(type=TokenType.VALUE, value="-q", line=7, indent=4),
+        Token(type=TokenType.NEWLINE, value="\n", line=7, indent=4),
+        Token(type=TokenType.EOF, value="EOF", line=8, indent=0),
+    ]
+    actual = lexer.parse()
+    assert actual == expected
+
+
+def test_multi_homogeneous_list(lexer):
+    lexer.text = (
+        "languages:\n\tpython:\n\t\tformatter:\n\t\t\targs @str:\n\t\t\t\t- format"
+        '\n\t\t\t\t- "-q"\n\t\t\t\t- "-q"\n'
+    )
+    expected = [
+        Token(type=TokenType.KEY, value="languages", line=1, indent=0),
+        Token(type=TokenType.TYPE, value="unknown", line=1, indent=0),
+        Token(type=TokenType.NEWLINE, value="\n", line=1, indent=0),
+        Token(type=TokenType.KEY, value="python", line=2, indent=1),
+        Token(type=TokenType.TYPE, value="unknown", line=2, indent=1),
+        Token(type=TokenType.NEWLINE, value="\n", line=2, indent=1),
+        Token(type=TokenType.KEY, value="formatter", line=3, indent=2),
+        Token(type=TokenType.TYPE, value="unknown", line=3, indent=2),
+        Token(type=TokenType.NEWLINE, value="\n", line=3, indent=2),
+        Token(type=TokenType.KEY, value="args", line=4, indent=3),
+        Token(type=TokenType.TYPE, value="str", line=4, indent=3),
+        Token(type=TokenType.NEWLINE, value="\n", line=4, indent=3),
+        Token(type=TokenType.OPERATOR, value="-", line=5, indent=4),
+        Token(type=TokenType.VALUE, value="format", line=5, indent=4),
+        Token(type=TokenType.NEWLINE, value="\n", line=5, indent=4),
+        Token(type=TokenType.OPERATOR, value="-", line=6, indent=4),
+        Token(type=TokenType.VALUE, value="-q", line=6, indent=4),
+        Token(type=TokenType.NEWLINE, value="\n", line=6, indent=4),
+        Token(type=TokenType.OPERATOR, value="-", line=7, indent=4),
+        Token(type=TokenType.VALUE, value="-q", line=7, indent=4),
+        Token(type=TokenType.NEWLINE, value="\n", line=7, indent=4),
+        Token(type=TokenType.EOF, value="EOF", line=8, indent=0),
+    ]
+    actual = lexer.parse()
+    assert actual == expected
