@@ -1,15 +1,20 @@
 from pathlib import Path
-
-from thsl.src.compiler import Compiler
 from typing import TextIO
 
+from thsl.exceptions import ThslLoadError
+from thsl.src.compiler import Compiler
+
 
 def loads(text: str) -> dict:
     compiler = Compiler(text)
-    return compiler.compile()
+    try:
+        return compiler.compile()
+    except Exception as err:  # noqa: BLE001
+        raise ThslLoadError from err
 
 
 def load(file_path: TextIO | Path) -> dict:
     if isinstance(file_path, Path):
-        return loads(file_path.open().read())
+        with file_path.open() as open_file:
+            return loads(open_file.read())
     return loads(file_path.read())
